/*
	LUSScreenSaver Plugin Interface
	Copyright (C) 2003 ONO,Masayuki.<mono101@skill-engineering.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "LUSSSPictureWidget.h"

LUSSSPictureWidget::LUSSSPictureWidget( QWidget* parent, const char* name )
	: QWidget( parent, name, WDestructiveClose ), m_nCnt( -1 )
{
	clearWFlags( WStyle_Title );
}

LUSSSPictureWidget::~LUSSSPictureWidget(  )
{
}

void LUSSSPictureWidget::Start()
{
	setBackgroundColor( QColor( 0, 0, 0 ) );
	erase();

	Config cfg( "LUSScreenSaver" );
	cfg.setGroup( "LUSSSPicture" );

	QString path = cfg.readEntry( "Path" );

	if ( path.isEmpty() || ! QFile::exists( path ) )
	{
		path = QPEApplication::documentDir() + "Image_Files/";
	}

	QDir oDir( path );
	oDir.setFilter( QDir::Files | QDir::Hidden );
	oDir.setSorting( QDir::Name );
	oDir.setNameFilter( "*.png;*.PNG;*.gif;*.GIF;*.jpg;*.JPG;*.bmp;*.BMP" );

	const QFileInfoList *pList = oDir.entryInfoList();
	QFileInfoListIterator it( *pList );
	QFileInfo *fi;
	while ( fi = it.current() )
	{
		m_FileList << fi->absFilePath();
		++it;
	}

	if ( m_FileList.count() > 0 )
	{
		m_nCnt = 0;
	}

	QTimer::singleShot( 10, this, SLOT( timerDo() ) );
}

void LUSSSPictureWidget::Stop()
{
	if ( !timer )
	{
		timer->stop();
		delete timer;
	}
}

void LUSSSPictureWidget::timerDo()
{
	if ( m_nCnt == -1 )
	{
		return;
	}

	QString imgPath = m_FileList[ m_nCnt ];
	
	if ( ++ m_nCnt >= ( signed int )m_FileList.count() )
	{
		m_nCnt = 0;
	}

	QImage img( imgPath );
	
	if ( img.height() > height() || img.width() > width() )
	{
		QSize sizeScaling;
		if ( img.height() > img.width() )
		{
			sizeScaling.setWidth( img.width() / ( img.height() / height() ) );
			sizeScaling.setHeight( height() );
		}else
		{
			sizeScaling.setWidth( width() );
			sizeScaling.setHeight( img.height() / ( img.width() / width() ) );
		}
		img = img.smoothScale( sizeScaling.width(), sizeScaling.height() );
	}

	QPoint imgTopLeft( ( width() - img.width() ) / 2, ( height() - img.height() ) / 2 );
	
	erase();
	bitBlt( this, imgTopLeft.x(), imgTopLeft.y(), &img );

	if ( m_nCnt == 1 )
	{
		Config cfg( "LUSScreenSaver" );
		cfg.setGroup( "LUSSSPicture" );
		timer = new QTimer(this);
		connect( timer, SIGNAL( timeout() ), this, SLOT( timerDo() ) );
		timer->start( cfg.readNumEntry( "Interval", 5 ) * 1000, false );
	}
}

void LUSSSPictureWidget::paintEvent( QPaintEvent * )
{
}

